View source: R/available_sections.R
| available_sections | R Documentation |
dawa()Simple function to list all available options for the section
parameter in dawa(). Useful when getting to know the base api function of
this package. To filter based on funciton usage you can provide format = "geojson" to ensure compatability with get_map_data() and func = "get_data" to ensure compatability with get_data().
available_sections(as_list = FALSE, format = NULL, verbose = TRUE, func = NULL)
as_list |
This options controls the output format. The output is either a named list or an atomic vector with the available sections |
format |
Specify a format type. The function now returns only available
sections that can respond with that format. Currently |
verbose |
whether or not to provide |
func |
Sepcify the function you would like to ensure section compatability with. |
The function returns either a named list or an atomic vector with the
available sections in the API. The format is decided by as_list.
available_sections()
available_sections(as_list = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.