connection_check: Check that *R* has access to resources at...

View source: R/status_check.R

connection_checkR Documentation

Check that R has access to resources at ⁠https://api.dataforsyningen.dk⁠

Description

Check that R has access to resources at ⁠https://api.dataforsyningen.dk⁠

Usage

connection_check()

Value

Returns a logical

See Also

Other Connection checks: status_check()

Examples


connection_check()



dawaR documentation built on Aug. 28, 2026, 1:06 a.m.